@@ -1,14 +1,16 @@
 """Rest Calls"""
 
+from typing import Any, Dict
 import requests
+import orjson
 
 from prismasase.config import Auth
 from prismasase import config, auth
-from prismasase.exceptions import SASEMissingParam
+from prismasase.exceptions import SASEBadRequest, SASEMissingParam
 
 
 @auth.Decorators.refresh_token
-def prisma_request(token: Auth, **kwargs):
+def prisma_request(token: Auth, **kwargs) -> Dict[str, Any]:
     """_summary_
 
     Args:
@@ -22,7 +24,10 @@ def prisma_request(token: Auth, **kwargs):
         timeout (int, optional): sets API call timeout. Defaults to 60
         delete_object (str, required|optional): Required if method is DELETE
         put_object (str, required|optional): Required if method is PUT
-
+        limit (int, Optional): The maximum number of results
+        offset (int, Optional): The offset of the result entry
+        name (string, Optional): The name of the entry
+        potition (str, Optional|Required): Required if inspecting Security Rules
     Returns:
         _type_: _description_
     """
@@ -31,19 +36,38 @@ def prisma_request(token: Auth, **kwargs):
         method: str = kwargs['method'].upper()
     except KeyError as err:
         raise SASEMissingParam(str(err))
-    params: dict = kwargs.get('params', None)
+    params: dict = kwargs.get('params', {})
+    try:
+        url: str = config.REST_API[url_type]
+    except KeyError as err:
+        raise SASEMissingParam(f'incorrect url type: {str(err)}')
+    if kwargs.get('name'):
+        params.update({'name': kwargs.get('name')})
+    if kwargs.get('limit'):
+        params.update({'limit': kwargs.get('limit')})
+    if kwargs.get('offset'):
+        params.update({'offset': kwargs.get('offset')})
     url: str = config.REST_API[url_type]
     headers = {"authorization": f"Bearer {token}", "content-type": "application/json"}
     data: str = kwargs.get('data', None)
     verify = kwargs.get('verify', True)
-    timeout: int = kwargs.get('timeout', 60)
+    timeout: int = kwargs.get('timeout', 90)
     if method.lower() == 'delete':
         delete_object = kwargs['delete_object']
         url = f"{url}/{delete_object}"
     if method.lower() == 'put':
         put_object = kwargs['put_object']
         url = f"{url}/{put_object}"
-    response = requests.request(method=method, url=url, headers=headers,
-                                data=data, params=params, verify=verify, timeout=timeout)
+    response = requests.request(method=method,
+                                url=url,
+                                headers=headers,
+                                data=data,
+                                params=params,
+                                verify=verify,
+                                timeout=timeout)
+    if '_error' in response.json():
+        raise SASEBadRequest(orjson.dumps(response.json()).decode('utf-8'))  # pylint: disable=no-member
+    if response.status_code == 400:
+        return response.json()
     response.raise_for_status()
     return response.json()
